@@ -14,7 +14,7 @@ use MooseX::Exception::Base::Stringify;
 
 use overload '""' => 'verbose';
 
-our $VERSION     = version->new('0.0.4');
+our $VERSION     = version->new('0.0.5');
 
 has error => (
     is             => 'rw',
@@ -72,7 +72,6 @@ sub verbose {
     for my $attribute (@attributes) {
         my $name = $attribute->name;
         next if !defined $self->$name;
-        next if !$attribute->does('MooseX::Exception::Stringify');
 
         local $_ = $self->$name;
         push @errors,
@@ -84,8 +83,7 @@ sub verbose {
 
     $verbose = defined $verbose ? $verbose : $self->_verbose;
     my $stack
-        = !defined $verbose ? $self->_stack
-        : $verbose == 0     ? ''
+        = $verbose == 0     ? ''
         : $verbose == 1     ? (split /\n/, $self->_stack)[0]
         :                     $self->_stack;
 
@@ -102,7 +100,7 @@ MooseX::Exception::Base - Base class for exceptions
 
 =head1 VERSION
 
-This documentation refers to MooseX::Exception::Base version 0.0.4.
+This documentation refers to MooseX::Exception::Base version 0.0.5.
 
 =head1 SYNOPSIS
 
@@ -192,12 +190,19 @@ Patches are welcome.
 
 =head1 ALSO SEE
 
+L<Throwable> probably should be use rather than this module for new projects
+as it's now best practice.
+
 L<Moose>, L<Exception::Class>
 
 =head1 AUTHOR
 
 Ivan Wills - (ivan.wills@gmail.com)
 
+=head1 CONTRIBUTORS
+
+Adam Herzog - adam@adamherzog.com
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright (c) 2012 Ivan Wills (14 Mullion Close Hornsby Heights NSW Australia 2077).
